@@ -50,10 +50,7 @@ package_deprecation_message = (
     "https://github.com/googleapis/python-dialogflow/issues."
 )
 
-warnings.warn(
-    package_deprecation_message,
-    DeprecationWarning
-)
+warnings.warn(package_deprecation_message, DeprecationWarning)
 
 
 class AgentsClient(agents_client.AgentsClient):
