@@ -24,6 +24,7 @@ from dialogflow_v2.proto import agent_pb2
 from dialogflow_v2.proto import audio_config_pb2
 from dialogflow_v2.proto import context_pb2
 from dialogflow_v2.proto import entity_type_pb2
+from dialogflow_v2.proto import environment_pb2
 from dialogflow_v2.proto import intent_pb2
 from dialogflow_v2.proto import session_entity_type_pb2
 from dialogflow_v2.proto import session_pb2
@@ -35,6 +36,7 @@ from google.protobuf import duration_pb2
 from google.protobuf import empty_pb2
 from google.protobuf import field_mask_pb2
 from google.protobuf import struct_pb2
+from google.protobuf import timestamp_pb2
 from google.rpc import status_pb2
 from google.type import latlng_pb2
 
@@ -46,6 +48,7 @@ _shared_modules = [
     empty_pb2,
     field_mask_pb2,
     struct_pb2,
+    timestamp_pb2,
     status_pb2,
     latlng_pb2,
 ]
@@ -55,6 +58,7 @@ _local_modules = [
     audio_config_pb2,
     context_pb2,
     entity_type_pb2,
+    environment_pb2,
     intent_pb2,
     session_entity_type_pb2,
     session_pb2,
