@@ -45,6 +45,8 @@ from dialogflow_v2beta1.proto import document_pb2
 from dialogflow_v2beta1.proto import document_pb2_grpc
 from dialogflow_v2beta1.proto import entity_type_pb2
 from dialogflow_v2beta1.proto import entity_type_pb2_grpc
+from dialogflow_v2beta1.proto import environment_pb2
+from dialogflow_v2beta1.proto import environment_pb2_grpc
 from dialogflow_v2beta1.proto import gcs_pb2
 from dialogflow_v2beta1.proto import validation_result_pb2
 from google.longrunning import operations_pb2
@@ -57,35 +59,7 @@ _GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class EntityTypesClient(object):
-    """
-    Entities are extracted from user input and represent parameters that are
-    meaningful to your application. For example, a date range, a proper name
-    such as a geographic location or landmark, and so on. Entities represent
-    actionable data for your application.
-
-    When you define an entity, you can also include synonyms that all map to
-    that entity. For example, "soft drink", "soda", "pop", and so on.
-
-    There are three types of entities:
-
-    -  **System** - entities that are defined by the Dialogflow API for
-       common data types such as date, time, currency, and so on. A system
-       entity is represented by the ``EntityType`` type.
-
-    -  **Custom** - entities that are defined by you that represent
-       actionable data that is meaningful to your application. For example,
-       you could define a ``pizza.sauce`` entity for red or white pizza
-       sauce, a ``pizza.cheese`` entity for the different types of cheese on
-       a pizza, a ``pizza.topping`` entity for different toppings, and so
-       on. A custom entity is represented by the ``EntityType`` type.
-
-    -  **User** - entities that are built for an individual user such as
-       favorites, preferences, playlists, and so on. A user entity is
-       represented by the ``SessionEntityType`` type.
-
-    For more information about entity types, see the `Dialogflow
-    documentation <https://cloud.google.com/dialogflow/docs/entities-overview>`__.
-    """
+    """Service for managing ``EntityTypes``."""
 
     SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
@@ -114,6 +88,20 @@ class EntityTypesClient(object):
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def project_agent_path(cls, project):
+        """Return a fully-qualified project_agent string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent", project=project
+        )
+
+    @classmethod
+    def agent_path(cls, project):
+        """Return a fully-qualified agent string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent", project=project
+        )
+
     @classmethod
     def entity_type_path(cls, project, entity_type):
         """Return a fully-qualified entity_type string."""
@@ -123,13 +111,6 @@ class EntityTypesClient(object):
             entity_type=entity_type,
         )
 
-    @classmethod
-    def project_agent_path(cls, project):
-        """Return a fully-qualified project_agent string."""
-        return google.api_core.path_template.expand(
-            "projects/{project}/agent", project=project
-        )
-
     def __init__(
         self,
         transport=None,
@@ -260,7 +241,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # Iterate over all results
             >>> for element in client.list_entity_types(parent):
@@ -279,11 +261,10 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The agent to list all entity types from. Format:
                 ``projects/<Project ID>/agent``.
-            language_code (str): Optional. The language to list entity synonyms for. If not specified,
-                the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             page_size (int): The maximum number of resources contained in the
                 underlying API response. If page streaming is performed per-
                 resource, this parameter does not affect the return value. If page
@@ -369,18 +350,18 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> response = client.get_entity_type(name)
 
         Args:
             name (str): Required. The name of the entity type. Format:
                 ``projects/<Project ID>/agent/entityTypes/<EntityType ID>``.
-            language_code (str): Optional. The language to retrieve entity synonyms for. If not
-                specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -448,7 +429,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `entity_type`:
             >>> entity_type = {}
@@ -462,11 +444,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.EntityType`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_type``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -544,11 +525,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.EntityType`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_type``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2beta1.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -620,7 +600,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
             >>>
             >>> client.delete_entity_type(name)
 
@@ -685,7 +666,6 @@ class EntityTypesClient(object):
     ):
         """
         Updates/Creates multiple entity types in the specified agent.
-
         Operation <response: ``BatchUpdateEntityTypesResponse``>
 
         Example:
@@ -693,7 +673,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> response = client.batch_update_entity_types(parent)
             >>>
@@ -717,11 +698,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.EntityTypeBatch`
-            language_code (str): Optional. The language of entity synonyms defined in ``entity_types``.
-                If not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2beta1.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -802,16 +782,16 @@ class EntityTypesClient(object):
         metadata=None,
     ):
         """
-        Deletes entity types in the specified agent.
-
-        Operation <response: ``google.protobuf.Empty``>
+        Deletes entity types in the specified agent. Operation <response:
+        ``google.protobuf.Empty``>
 
         Example:
             >>> import dialogflow_v2beta1
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.project_agent_path('[PROJECT]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `entity_type_names`:
             >>> entity_type_names = []
@@ -830,8 +810,8 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The name of the agent to delete all entities types for.
                 Format: ``projects/<Project ID>/agent``.
-            entity_type_names (list[str]): Required. The names entity types to delete. All names must point to the
-                same agent as ``parent``.
+            entity_type_names (list[str]): Required. The names entity types to delete. All names must point to
+                the same agent as ``parent``.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -907,7 +887,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `entities`:
             >>> entities = []
@@ -930,11 +911,10 @@ class EntityTypesClient(object):
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.Entity`
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
@@ -1002,8 +982,8 @@ class EntityTypesClient(object):
         metadata=None,
     ):
         """
-        Updates or creates multiple entities in the specified entity type. This
-        method does not affect entities in the entity type that aren't
+        Updates or creates multiple entities in the specified entity type.
+        This method does not affect entities in the entity type that aren't
         explicitly specified in the request.
 
         Operation <response: ``google.protobuf.Empty``>
@@ -1013,7 +993,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `entities`:
             >>> entities = []
@@ -1030,17 +1011,17 @@ class EntityTypesClient(object):
             >>> metadata = response.metadata()
 
         Args:
-            parent (str): Required. The name of the entity type to update or create entities in.
-                Format: ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
+            parent (str): Required. The name of the entity type to update or create entities
+                in. Format:
+                ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
             entities (list[Union[dict, ~google.cloud.dialogflow_v2beta1.types.Entity]]): Required. The entities to update or create.
 
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.Entity`
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             update_mask (Union[dict, ~google.cloud.dialogflow_v2beta1.types.FieldMask]): Optional. The mask to control which fields get updated.
 
                 If a dict is provided, it must be of the same form as the protobuf
@@ -1123,7 +1104,8 @@ class EntityTypesClient(object):
             >>>
             >>> client = dialogflow_v2beta1.EntityTypesClient()
             >>>
-            >>> parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+            >>> # TODO: Initialize `parent`:
+            >>> parent = ''
             >>>
             >>> # TODO: Initialize `entity_values`:
             >>> entity_values = []
@@ -1142,14 +1124,13 @@ class EntityTypesClient(object):
         Args:
             parent (str): Required. The name of the entity type to delete entries for. Format:
                 ``projects/<Project ID>/agent/entityTypes/<Entity Type ID>``.
-            entity_values (list[str]): Required. The reference ``values`` of the entities to delete. Note that
-                these are not fully-qualified names, i.e. they don't start with
+            entity_values (list[str]): Required. The reference ``values`` of the entities to delete. Note
+                that these are not fully-qualified names, i.e. they don't start with
                 ``projects/<Project ID>``.
-            language_code (str): Optional. The language of entity synonyms defined in ``entities``. If
-                not specified, the agent's default language is used. `Many
-                languages <https://cloud.google.com/dialogflow/docs/reference/language>`__
-                are supported. Note: languages must be enabled in the agent before they
-                can be used.
+            language_code (str): Optional. The language used to access language-specific data. If not
+                specified, the agent's default language is used. For more information,
+                see `Multilingual intent and entity
+                data <https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
                 to retry requests. If ``None`` is specified, requests will
                 be retried using a default configuration.
